"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioGroup = exports.Radio = exports["default"] = exports.RadioGroupContext = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));

var _jsxRuntime = require("react/jsx-runtime");

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Base = _interopRequireDefault(require("../Base.core"));

var _Text = _interopRequireDefault(require("../Text/Text"));

require("./Radio.scss");

/* eslint react/prop-types: 0 */
var RadioGroupContext = /*#__PURE__*/_react["default"].createContext();
/**
 * The `<input type="radio">` defines a radio button.
 * RadioButton buttons are normally presented in radio groups (a collection of radio buttons describing a set of related options). Only one radio button in a group can be selected at the same time.
 */


exports.RadioGroupContext = RadioGroupContext;

var Radio = function Radio(_ref) {
  var label = _ref.label,
      className = _ref.className,
      _ref$defaultChecked = _ref.defaultChecked,
      defaultChecked = _ref$defaultChecked === void 0 ? false : _ref$defaultChecked,
      onClick = _ref.onClick,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {
    return null;
  } : _ref$onChange,
      checked = _ref.checked,
      value = _ref.value,
      name = _ref.name,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, ["label", "className", "defaultChecked", "onClick", "onChange", "checked", "value", "name"]);
  var radioGroupContext = (0, _react.useContext)(RadioGroupContext) || {};
  var contextValue = radioGroupContext.value;
  var setContextState = radioGroupContext.setContextState;

  var _useState = (0, _react.useState)(defaultChecked === undefined ? defaultChecked : checked),
      checkedState = _useState[0],
      setCheckedState = _useState[1];

  (0, _react.useEffect)(function () {
    if (contextValue === undefined) {
      return;
    }

    if (value) {
      setCheckedState(contextValue === value.toString());
    }
  }, [contextValue, setCheckedState, value]);

  var onClickHandler = function onClickHandler(event) {
    var value = event.target.value;

    if (setContextState && event.target.checked === true) {
      setContextState({
        value: value
      });
    }

    setCheckedState(!checkedState);

    if (onClick) {
      onClick(event, event.target.checked === true ? value : undefined);
    }
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
      elementType: "input",
      type: "radio",
      className: (0, _classnames["default"])('sui-studio-doc-radio', className),
      onClick: onClickHandler,
      onChange: onChange,
      checked: checkedState,
      "aria-label": label || value,
      value: value,
      name: name || radioGroupContext.name
    })), (label || value) && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text["default"], {
      elementType: "label",
      children: label || value
    })]
  });
};

exports.Radio = Radio;
Radio.displayName = 'Radio';
Radio.defaultProps = {
  checked: false
};
/**
 * Radio options element wrapper
 */

var RadioGroup = function RadioGroup(_ref2) {
  var className = _ref2.className,
      children = _ref2.children,
      _ref2$elementType = _ref2.elementType,
      elementType = _ref2$elementType === void 0 ? 'div' : _ref2$elementType,
      value = _ref2.value,
      label = _ref2.label,
      name = _ref2.name,
      onChange = _ref2.onChange,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, ["className", "children", "elementType", "value", "label", "name", "onChange"]);

  var _useState2 = (0, _react.useState)({
    name: name,
    label: label,
    value: value
  }),
      context = _useState2[0],
      setContext = _useState2[1];

  var setContextState = function setContextState(newArguments) {
    if (newArguments === void 0) {
      newArguments = {};
    }

    var newContext = (0, _extends2["default"])({}, context, newArguments);

    if (onChange) {
      onChange(newContext.value);
    }

    setContext(newContext);
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Base["default"], (0, _extends2["default"])({}, props, {
    className: (0, _classnames["default"])('sui-studio-doc-radio-group', className),
    elementType: elementType,
    role: "radiogroup",
    "aria-labelledby": label,
    name: name,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(RadioGroupContext.Provider, {
      value: (0, _extends2["default"])({}, context, {
        setContextState: setContextState
      }),
      children: children
    })
  }));
};

exports.RadioGroup = RadioGroup;
RadioGroup.displayName = 'RadioGroup';
RadioGroup.defaultProps = {};
var _default = Radio;
exports["default"] = _default;