"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioButtonGroup = exports.RadioButton = exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));

var _jsxRuntime = require("react/jsx-runtime");

var _react = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Radio = require("./Radio");

var _Button = require("../Button/Button");

require("./Radio.scss");

/* eslint react/prop-types: 0 */

/**
 * The `<input type="radio">` defines a radio button styled like a button.
 * RadioButton buttons are normally presented in radio groups (a collection of radio buttons describing a set of related options). Only one radio button in a group can be selected at the same time.
 */
var RadioButton = function RadioButton(_ref) {
  var label = _ref.label,
      value = _ref.value,
      className = _ref.className,
      onClick = _ref.onClick,
      onChange = _ref.onChange,
      _ref$defaultChecked = _ref.defaultChecked,
      defaultChecked = _ref$defaultChecked === void 0 ? false : _ref$defaultChecked,
      checked = _ref.checked,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref, ["label", "value", "className", "onClick", "onChange", "defaultChecked", "checked"]);
  var radioGroupContext = (0, _react.useContext)(_Radio.RadioGroupContext) || {};
  var contextValue = radioGroupContext.value;
  var setContextState = radioGroupContext.setContextState;

  var _useState = (0, _react.useState)(defaultChecked === undefined ? defaultChecked : checked),
      checkedState = _useState[0],
      setCheckedState = _useState[1];

  (0, _react.useEffect)(function () {
    if (contextValue === undefined) {
      return;
    }

    if (value) {
      setCheckedState(contextValue === value.toString());
    }
  }, [contextValue, setCheckedState, value]);

  var onClickHandler = function onClickHandler(event) {
    if (setContextState) {
      setContextState({
        value: value
      });
    }

    setCheckedState(!checkedState);

    if (onClick) {
      onClick(event, !checkedState === true ? value : undefined);
    }
  };

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.Button, (0, _extends2["default"])({}, props, {
    onClick: onClickHandler,
    className: (0, _classnames["default"])('sui-studio-doc-radio-button', {
      'sui-studio-doc-radio-button--checked': checkedState
    }, className),
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Radio.Radio, {
      className: "sui-studio-doc-radio-button__radio",
      onChange: onChange,
      defaultChecked: defaultChecked,
      checked: checkedState,
      label: label,
      value: value
    })
  }));
};

exports.RadioButton = RadioButton;
RadioButton.displayName = 'RadioButton';
RadioButton.defaultProps = {
  checked: false
};
/**
 * Radio button options element wrapper
 */

var RadioButtonGroup = function RadioButtonGroup(_ref2) {
  var className = _ref2.className,
      children = _ref2.children,
      _ref2$elementType = _ref2.elementType,
      elementType = _ref2$elementType === void 0 ? 'div' : _ref2$elementType,
      onChange = _ref2.onChange,
      name = _ref2.name,
      value = _ref2.value,
      props = (0, _objectWithoutPropertiesLoose2["default"])(_ref2, ["className", "children", "elementType", "onChange", "name", "value"]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Radio.RadioGroup, {
    onChange: onChange,
    name: name,
    value: value,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.ButtonGroup, (0, _extends2["default"])({}, props, {
      className: (0, _classnames["default"])('sui-studio-doc-radio-button', className),
      elementType: elementType,
      children: children
    }))
  });
};

exports.RadioButtonGroup = RadioButtonGroup;
RadioButtonGroup.displayName = 'RadioButtonGroup';
RadioButtonGroup.defaultProps = {};
var _default = RadioButton;
exports["default"] = _default;